/* 
 * Phidget Hello World Program for all devices
 * (c) Phidgets 2015
 */

using System;
using Phidget22;
using Phidget22.Events;

namespace HelloWorld
{
    class Program
    {
        // ========= General C# Functions =============

        static void printError(ErrorCode number, String description)
        {
            Console.WriteLine("Error on function call: {0} - {1}!", number, description);

        }

        // ========= Event Handling Functions =============

        static void manager_Attach(object sender, ManagerAttachEventArgs e)
        {
            int serialNumber;
            String name;

            try{
                serialNumber = e.Channel.DeviceSerialNumber;
                name = e.Channel.DeviceName;
                Console.WriteLine("Hello Device {0},  Serial Number: {1}!", name, serialNumber.ToString());
            }
            catch (PhidgetException ex)
            {
                printError(ex.ErrorCode, ex.Description);
            }
        }

        static void manager_Detach(object sender, ManagerDetachEventArgs e)
        {
            int serialNumber;
            String name;

            try
            {
                serialNumber = e.Channel.DeviceSerialNumber;
                name = e.Channel.DeviceName;
                Console.WriteLine("Goodbye Device {0},  Serial Number: {1}", name, serialNumber.ToString());
            }
            catch (PhidgetException ex)
            {
                printError(ex.ErrorCode, ex.Description);
            }
        }

        // =========== Main Code ==========

        static void Main(string[] args)
        {
            // No exception thrown on create
            Manager manager = new Manager();

            try
            {
                manager.Attach += new ManagerAttachEventHandler(manager_Attach);
                manager.Detach += new ManagerDetachEventHandler(manager_Detach);
            } 
            catch (PhidgetException ex)
            {
                printError(ex.ErrorCode, ex.Description);
            }

            // No exception thrown on open
            manager.Open();

			Console.WriteLine("Phidget Simple Playground (plug and unplug devices)");
            Console.WriteLine("Press Enter to end anytime");
            Console.Read();

            Console.WriteLine("Closing....");
            try
            {
                manager.Attach -= new ManagerAttachEventHandler(manager_Attach);
                manager.Detach -= new ManagerDetachEventHandler(manager_Detach);
                manager.Close();
            }
            catch (PhidgetException ex)
            {
                printError(ex.ErrorCode, ex.Description);
            }

            manager = null;
        }
    }
}